=======
History
=======

0.2.1 (2023-06-14)
------------------

* Fixed documentation.

0.2.0 (2023-06-14)
------------------

* Upgraded to SPADE>=3.3 (older versions are deprecated).
* Upgraded to Python>=3.8 (older versions are deprecated).

0.1.2 (2018-09-17)
------------------

* Added requirements file.
* Fixed tox configuration for CI.
* Fixed readthedocs configuration.

0.1.0 (2018-09-17)
------------------

* First release on PyPI.
